Coverage for src/airball/__init__.py: 100%

1'''

2# Flybys in `REBOUND`

3- A package for implementing flybys in [hannorein/rebound](https://github.com/hannorein/rebound)

4'''

5 from .core import (add_star_to_sim, flyby, flybys, successive_flybys, concurrent_flybys)

6 from .environments import (StellarEnvironment, LocalNeighborhood, OpenCluster, GlobularCluster, GalacticBulge, GalacticCore)

7 from .analytic import (relative_energy_change, energy_change_adiabatic_estimate, eccentricity_change_adiabatic_estimate)

8 from .imf import (IMF)

9 from .stars import (Star, Stars)

10 from .tools import (UnitSet)

11

12 __version__ = 'v0.5.0'